log_format = (
    '%(asctime)s - '
    '%(name)s - '
    '%(funcName)s - '
    '%(levelname)s\n'
    '%(message)s'
)
bold_seq = '\033[1m'
colorlog_format = (
    f'{bold_seq} '
    '%(log_color)s '
    f'{log_format}'
)




import requests
import asyncio


class CamperException:
    def __init__(self):
        pass

    @staticmethod
    @asyncio.coroutine
    def __post_error_message(url, message, extra):
        try:
            body = {"error": message, "extra": extra}
            requests.post(
                url=url,
                json=body
            )
        except Exception as e:
            from .Log import CamperLogger
            logger = CamperLogger('camper_exception', record=True)
            logger.error(e)

    @classmethod
    def exception_catcher(cls, **kwargs):
        default = kwargs.get('default')
        default_callback = kwargs.get('callback')
        error_callback = kwargs.get('error_callback')
        log_path = kwargs.get('log_path')
        record = kwargs.get('record')
        post_endpoint = kwargs.get('post_endpoint')
        extra_data = kwargs.get('extra')

        def wrapper(func):
            def run_func(*args, **kwargs):
                try:
                    return func(*args, **kwargs)
                except Exception as e:
                    from .Log import CamperLogger
                    logger = CamperLogger('camper_exception', log_path=log_path, record=record)
                    err = " Path : {path} \n" \
                          " Function : {func} \n" \
                          " Error: {error}".format(
                        path=str(func.__code__.co_filename),
                        func=func.__name__,
                        error=e
                    )
                    if post_endpoint is not None and type(post_endpoint) == str and len(post_endpoint) > 0:
                        loop = asyncio.get_event_loop()
                        loop.run_until_complete(
                            cls.__post_error_message(url=post_endpoint, message=str(e), extra=extra_data))
                        loop.close()
                    if error_callback is not None:
                        error_callback(e)
                    logger.error(err)
                    if default_callback is not None:
                        return default_callback(default)
                    return default

            return run_func

        return wrapper



import logging
import colorlog
from .Static import *
from Camper.ExceptionCatcher import CamperException


def error_handler(err):
    print(err)


class CamperLogger:

    @CamperException.exception_catcher(error_callback=error_handler)
    def __init__(self, logger_name, **kwargs):
        self.name = logger_name
        self.debug = kwargs.get('debug')
        self.log_path = kwargs.get('log_path')
        self.record = kwargs.get('record')
        self.logger = None
        self.__init_logger()

    @CamperException.exception_catcher(error_callback=error_handler)
    def __init_logger(self):
        colorlog.basicConfig(format=colorlog_format)
        self.logger = logging.getLogger(self.name)
        if self.debug:
            self.logger.setLevel(logging.DEBUG)
        else:
            self.logger.setLevel(logging.INFO)
        if self.log_path is None or self.log_path == '' or type(self.log_path) != str:
            self.log_path = './'
        elif not self.log_path.endswith('/'):
            self.log_path += '/'

    @CamperException.exception_catcher(error_callback=error_handler)
    def warning(self, message, file_name="app-warning"):
        if self.logger is not None and message is not None:
            if self.record:
                file_name = "app-warning" if file_name is None or file_name == "" else file_name
                file_name = file_name.replace(".", "")
                fh = logging.FileHandler(self.log_path + (file_name + '.log'))
                fh.setLevel(logging.WARNING)
                formatter = logging.Formatter(log_format)
                fh.setFormatter(formatter)
                self.logger.addHandler(fh)
                self.logger.warning(message)
                self.logger.removeHandler(fh)
            else:
                self.logger.warning(message)

    @CamperException.exception_catcher(error_callback=error_handler)
    def error(self, message, file_name="app-error"):
        if self.logger is not None and message is not None:
            if self.record:
                file_name = "app-error" if file_name is None or file_name == "" else file_name
                file_name = file_name.replace(".", "")
                fh = logging.FileHandler(self.log_path + (file_name + '.log'))
                fh.setLevel(logging.ERROR)
                formatter = logging.Formatter(log_format)
                fh.setFormatter(formatter)
                self.logger.addHandler(fh)
                self.logger.error(message)
                self.logger.removeHandler(fh)
            else:
                self.logger.error(message)

    @CamperException.exception_catcher(error_callback=error_handler)
    def info(self, message, file_name="app-info"):
        if self.logger is not None and message is not None:
            if self.record:
                file_name = "app-info" if file_name is None or file_name == "" else file_name
                file_name = file_name.replace(".", "")
                fh = logging.FileHandler(self.log_path + (file_name + '.log'))
                fh.setLevel(logging.INFO)
                formatter = logging.Formatter(log_format)
                fh.setFormatter(formatter)
                self.logger.addHandler(fh)
                self.logger.info(message)
                self.logger.removeHandler(fh)
            else:
                self.logger.info(message)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="Camper-Logger-Exception",
    version="0.1.3",
    author="Abdullah KULCU",
    author_email="abdullahkulcu@outlook.com",
    description="Python logging and exception catcher library for lazy peoples",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/abdullahkulcu/Camper-Logger-Exception",
    packages=setuptools.find_packages(),
    install_requires=[
        'colorlog',
        "requests"
    ],
    classifiers=[
        "Programming Language :: Python :: 3.6",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
